Reads a FreeSurfer color lookup table and adds hex colour codes for use in plotting.
Arguments
- color_lut
Path to a color table file, or a data.frame that passes
is_ctab().
Value
A data.frame with the original columns plus roi (zero-padded
index) and color (hex colour code).